pub struct PodGroup {
pub metadata: ObjectMeta,
pub spec: PodGroupSpec,
pub status: Option<PodGroupStatus>,
}Expand description
PodGroup represents a runtime instance of pods grouped together. PodGroups are created by workload controllers (Job, LWS, JobSet, etc…) from Workload.podGroupTemplates. PodGroup API enablement is toggled by the GenericWorkload feature gate.
Fields
metadata: ObjectMetaStandard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
spec: PodGroupSpecSpec defines the desired state of the PodGroup.
status: Option<PodGroupStatus>Status represents the current observed state of the PodGroup.