pub struct PodGroupSchedulingConstraints {
pub topology: Option<Vec<TopologyConstraint>>,
}Expand description
PodGroupSchedulingConstraints defines scheduling constraints (e.g. topology) for a PodGroup.
Fields
topology: Option<Vec<TopologyConstraint>>Topology defines the topology constraints for the pod group. Currently only a single topology constraint can be specified. This may change in the future.