pub struct PodGroupSchedulingPolicy {
pub basic: Option<BasicSchedulingPolicy>,
pub gang: Option<GangSchedulingPolicy>,
}Expand description
PodGroupSchedulingPolicy defines the scheduling configuration for a PodGroup. Exactly one policy must be set.
Fields
basic: Option<BasicSchedulingPolicy>Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
gang: Option<GangSchedulingPolicy>Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.