PodGroupSpec

Struct PodGroupSpec 

pub struct PodGroupSpec {
    pub disruption_mode: Option<String>,
    pub pod_group_template_ref: Option<PodGroupTemplateReference>,
    pub priority: Option<i32>,
    pub priority_class_name: Option<String>,
    pub resource_claims: Option<Vec<PodGroupResourceClaim>>,
    pub scheduling_constraints: Option<PodGroupSchedulingConstraints>,
    pub scheduling_policy: PodGroupSchedulingPolicy,
}
PodGroupSpec defines the desired state of a PodGroup.

Fields

disruption_mode: Option<String>

DisruptionMode defines the mode in which a given PodGroup can be disrupted. Controllers are expected to fill this field by copying it from a PodGroupTemplate. One of Pod, PodGroup. Defaults to Pod if unset. This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.

pod_group_template_ref: Option<PodGroupTemplateReference>

PodGroupTemplateRef references an optional PodGroup template within other object (e.g. Workload) that was used to create the PodGroup. This field is immutable.

priority: Option<i32>

Priority is the value of priority of this pod group. Various system components use this field to find the priority of the pod group. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority. This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.

priority_class_name: Option<String>

PriorityClassName defines the priority that should be considered when scheduling this pod group. Controllers are expected to fill this field by copying it from a PodGroupTemplate. Otherwise, it is validated and resolved similarly to the PriorityClassName on PodGroupTemplate (i.e. if no priority class is specified, admission control can set this to the global default priority class if it exists. Otherwise, the pod group’s priority will be zero). This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.

resource_claims: Option<Vec<PodGroupResourceClaim>>

ResourceClaims defines which ResourceClaims may be shared among Pods in the group. Pods consume the devices allocated to a PodGroup’s claim by defining a claim in its own Spec.ResourceClaims that matches the PodGroup’s claim exactly. The claim must have the same name and refer to the same ResourceClaim or ResourceClaimTemplate.

This is an alpha-level field and requires that the DRAWorkloadResourceClaims feature gate is enabled.

This field is immutable.

scheduling_constraints: Option<PodGroupSchedulingConstraints>

SchedulingConstraints defines optional scheduling constraints (e.g. topology) for this PodGroup. Controllers are expected to fill this field by copying it from a PodGroupTemplate. This field is immutable. This field is only available when the TopologyAwareWorkloadScheduling feature gate is enabled.

scheduling_policy: PodGroupSchedulingPolicy

SchedulingPolicy defines the scheduling policy for this instance of the PodGroup. Controllers are expected to fill this field by copying it from a PodGroupTemplate. This field is immutable.