pub struct PodGroupStatus {
pub conditions: Option<Vec<Condition>>,
pub resource_claim_statuses: Option<Vec<PodGroupResourceClaimStatus>>,
}Expand description
PodGroupStatus represents information about the status of a pod group.
Fields
conditions: Option<Vec<Condition>>Conditions represent the latest observations of the PodGroup’s state.
Known condition types: - “PodGroupScheduled”: Indicates whether the scheduling requirement has been satisfied. - “DisruptionTarget”: Indicates whether the PodGroup is about to be terminated due to disruption such as preemption.
Known reasons for the PodGroupScheduled condition: - “Unschedulable”: The PodGroup cannot be scheduled due to resource constraints, affinity/anti-affinity rules, or insufficient capacity for the gang.
- “SchedulerError”: The PodGroup cannot be scheduled due to some internal error that happened during scheduling, for example due to nodeAffinity parsing errors.
Known reasons for the DisruptionTarget condition: - “PreemptionByScheduler”: The PodGroup was preempted by the scheduler to make room for higher-priority PodGroups or Pods.
resource_claim_statuses: Option<Vec<PodGroupResourceClaimStatus>>Status of resource claims.