pub struct TopologyConstraint {
pub key: String,
}Expand description
TopologyConstraint defines a topology constraint for a PodGroup.
Fields
key: StringKey specifies the key of the node label representing the topology domain. All pods within the PodGroup must be colocated within the same domain instance. Different PodGroups can land on different domain instances even if they derive from the same PodGroupTemplate. Examples: “topology.kubernetes.io/rack”